@@ -3,12 +3,10 @@
 import pandas as pd
 
 
-def missing_data_check(excel_file, sheet_name, column_name):
+def missing_data_check(column_df):
 
-    df = pd.read_excel(excel_file, sheet_name=sheet_name,
-                       usecols=[column_name])
-
-    missing_data = df[column_name].isnull()
+    
+    missing_data = column_df.isnull()
 
     if missing_data.any():
 
@@ -23,7 +21,7 @@ def missing_data_check(excel_file, sheet_name, column_name):
                 } 
              
     else:
-        False
+        return True
 
 
 if __name__ == "__main__":
